@@ -72,7 +72,6 @@ def config(ctx, config, service_name, full=True):
 
 
 @composer.command(name='reload', help="Switches to project in current working directory.")
-@click.option('-i', '--images-url', default="https://github.com/marcwimmer/wodoo-images")
 @click.option("--demo", is_flag=True, help="Enabled demo data.")
 @click.option("-d", "--db", required=False)
 @click.option("-p", "--proxy-port", required=False)
@@ -82,9 +81,8 @@ def config(ctx, config, service_name, full=True):
 @click.option("-c", "--additional_config", help="Base64 encoded configuration like in settings")
 @pass_config
 @click.pass_context
-def do_reload(ctx, config, db, demo, proxy_port, mailclient_gui_port, headless, devmode, additional_config, images_url):
+def do_reload(ctx, config, db, demo, proxy_port, mailclient_gui_port, headless, devmode, additional_config):
     from .myconfigparser import MyConfigParser
-    config.images_url = images_url
 
     if headless and proxy_port:
         click.secho("Proxy Port and headless together not compatible.", fg='red')
@@ -198,10 +196,19 @@ def _download_images(config):
         subprocess.run([
             "git",
             "clone",
-            config.images_url,
+            config.IMAGES_URL,
             config.dirs['images']
         ])
     subprocess.run(["git", "pull"], cwd=config.dirs['images'])
+    branch = subprocess.check_output(["git", "rev-parse", "--abbrev-ref", "HEAD"], cwd=config.dirs['images'], encoding='utf-8').strip()
+    if branch != config.IMAGES_BRANCH:
+        if subprocess.check_output(["git", "diff", "--stat"], cwd=config.dirs['images']).strip():
+            click.secho(f"{config.dirs['images']} is dirty - cannot switch to branch {config.IMAGES_BRANCH}", fg='red')
+            sys.exit(-1)
+        subprocess.run(["git", "checkout", "-f", config.IMAGES_BRANCH], cwd=config.dirs['images'])
+        subprocess.run(["git", "clean", "-xdff"], cwd=config.dirs['images'])
+        subprocess.run(["git", "pull"], cwd=config.dirs['images'])
+
 
 
 def _prepare_filesystem(config):
